summaryrefslogtreecommitdiffstats
path: root/qt/qextscintillalexertex.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-11-30 12:33:18 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-11-30 12:33:18 -0600
commit03bc485016127d419bbbbc3cfb09e21e8754b383 (patch)
treecad8234bcf26063239ac7a565298b897ffdeef57 /qt/qextscintillalexertex.h
parent664e37abfe5c796c1279b8295fb030f126b0a7d8 (diff)
downloadtqscintilla-03bc485016127d419bbbbc3cfb09e21e8754b383.tar.gz
tqscintilla-03bc485016127d419bbbbc3cfb09e21e8754b383.zip
Initial automated TQt conversion
Diffstat (limited to 'qt/qextscintillalexertex.h')
-rw-r--r--qt/qextscintillalexertex.h31
1 files changed, 16 insertions, 15 deletions
diff --git a/qt/qextscintillalexertex.h b/qt/qextscintillalexertex.h
index f46960c..250f92d 100644
--- a/qt/qextscintillalexertex.h
+++ b/qt/qextscintillalexertex.h
@@ -3,38 +3,39 @@
// Copyright (c) 2006
// Riverbank Computing Limited <info@riverbankcomputing.co.uk>
//
-// This file is part of QScintilla.
+// This file is part of TQScintilla.
//
-// This copy of QScintilla is free software; you can redistribute it and/or
+// This copy of TQScintilla is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2, or (at your option) any
// later version.
//
-// QScintilla is supplied in the hope that it will be useful, but WITHOUT ANY
+// TQScintilla is supplied in the hope that it will be useful, but WITHOUT ANY
// WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
// FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
// details.
//
// You should have received a copy of the GNU General Public License along with
-// QScintilla; see the file LICENSE. If not, write to the Free Software
+// TQScintilla; see the file LICENSE. If not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
-#ifndef QEXTSCINTILLALEXERTEX_H
-#define QEXTSCINTILLALEXERTEX_H
+#ifndef TQEXTSCINTILLALEXERTEX_H
+#define TQEXTSCINTILLALEXERTEX_H
-#include <qobject.h>
+#include <tqobject.h>
-#include <qextscintillaglobal.h>
-#include <qextscintillalexer.h>
+#include <tqextscintillaglobal.h>
+#include <tqextscintillalexer.h>
//! \brief The QextScintillaLexerTeX class encapsulates the Scintilla TeX
//! lexer.
-class QEXTSCINTILLA_EXPORT QextScintillaLexerTeX : public QextScintillaLexer
+class TQEXTSCINTILLA_EXPORT QextScintillaLexerTeX : public QextScintillaLexer
{
Q_OBJECT
+ TQ_OBJECT
public:
//! This enum defines the meanings of the different styles used by the
@@ -61,7 +62,7 @@ public:
//! Construct a QextScintillaLexerTeX with parent \a parent and name
//! \a name. \a parent is typically the QextScintilla instance.
- QextScintillaLexerTeX(QObject *parent = 0,const char *name = 0);
+ QextScintillaLexerTeX(TQObject *parent = 0,const char *name = 0);
//! Destroys the QextScintillaLexerTeX instance.
virtual ~QextScintillaLexerTeX();
@@ -80,19 +81,19 @@ public:
//! \a style.
//!
//! \sa paper()
- QColor color(int style) const;
+ TQColor color(int style) const;
//! Returns the set of keywords for the keyword set \a set recognised
//! by the lexer as a space separated string.
const char *keywords(int set) const;
//! Returns the descriptive name for style number \a style. If the
//! style is invalid for this language then QString::null is returned.
//! This is intended to be used in user preference dialogs.
- QString description(int style) const;
+ TQString description(int style) const;
private:
-#if defined(Q_DISABLE_COPY)
+#if defined(TQ_DISABLE_COPY)
QextScintillaLexerTeX(const QextScintillaLexerTeX &);
QextScintillaLexerTeX &operator=(const QextScintillaLexerTeX &);
#endif
@@ -80,19 +81,19 @@ public:
const char *keywords(int set) const;
//! Returns the descriptive name for style number \a style. If the
- //! style is invalid for this language then QString::null is returned.
+ //! style is invalid for this language then TQString() is returned.
//! This is intended to be used in user preference dialogs.